@@ -2,15 +2,14 @@
 #' @keywords dplot
 #' 
 ceplane_base_params <- function(he,
-                                wtp,
                                 graph_params) {
   
   c(list(
     setup = setup_params(graph_params),
     points = points_params(graph_params),
     polygon = polygon_params(graph_params),
-    k_txt = k_text(graph_params, wtp),
-    wtp = wtp,
+    k_txt = k_text(graph_params, graph_params$wtp_value),
+    wtp = graph_params$wtp_value,
     ref_first = graph_params$ref_first),
     icer_params(graph_params, he))
 }
