@@ -5,6 +5,7 @@
 #' @param graph_params Type of plot device
 #' @param cri_params Credible interval parameters
 #' @return list
+#' @keywords internal
 #' 
 eib_params_base <- function(he,
                             graph_params,
@@ -23,9 +24,9 @@ eib_params_base <- function(he,
     xlab = graph_params$xlab,
     ylab = graph_params$ylab,
     main = graph_params$main,
-    col = graph_params$line$colors,
+    col = graph_params$line$color,
     lwd = graph_params$line$lwd,
-    lty = graph_params$line$types,
+    lty = graph_params$line$type,
     type = "l",
     xlim = range(he$k),
     ylim = ylim)
