@@ -11,31 +11,41 @@
 #' 
 evppi_plot_ggplot <- function(evppi_obj,
                               pos_legend = c(0, 0.8),
-                              col = c(1,1),
+                              col = c(1, 1),
                               ...) {
   
   extra_args <- list(...)
   
-  plot_dat <-
-    evppi_obj[c("evi", "evppi", "k")] %>% 
-    bind_rows() %>% 
-    ##TODO: for >1 evppi
-    melt(id.vars = "k") %>% 
-    mutate(variable = as.character(.data$variable),
-           variable = ifelse(.data$variable == "evppi",
-                             paste("EVPPI for",
-                                   evppi_obj$parameters),
-                             "EVPI"))
+  # Combine evi and evppi into a tidy format
+  plot_dat <- evppi_obj[c("evi", "evppi", "k")] %>%
+    bind_rows() %>%
+    pivot_longer(
+      cols = -"k",
+      names_to = "variable",
+      values_to = "value"
+    ) %>%
+    mutate(
+      variable = as.character(.data$variable),
+      variable = ifelse(.data$variable == "evppi",
+                        paste("EVPPI for", evppi_obj$parameters),
+                        "EVPI")
+    )
   
-  theme_add <- Filter(f = \(val) ggplot2::is_theme(val), x = extra_args)
+  # Extract optional ggplot2 themes from extra arguments
+  theme_add <- Filter(ggplot2::is_theme, extra_args)
   
+  # Extract size vector or use default
   size <- purrr::pluck(extra_args, "size", .default = c(1, 0.5))
   
+  # Prepare legend position
   legend_params <- make_legend_ggplot(evppi_obj, pos_legend)
   
+  # Build the ggplot
   ggplot(plot_dat,
          aes(x = .data$k, y = .data$value,
-             group = .data$variable, size = .data$variable, color = .data$variable)) +
+             group = .data$variable,
+             size = .data$variable,
+             color = .data$variable)) +
     geom_line() +
     theme_default() +
     theme_add +
@@ -46,4 +56,3 @@ evppi_plot_ggplot <- function(evppi_obj,
     xlab("Willingness to pay") +
     ylab("")
 }
-
