@@ -7,7 +7,8 @@
 
 
 test_that("eib.plot_ggplot draws correctly", {
-  load("ce.RData")
+  load(test_path("testdata", "ce.RData"))
+  
   he <- BCEA::bcea(eff, cost)
   
   eib_plot <- eib.plot(he, graph = "ggplot2", title = "my title")
